# Installation
> `npm install --save @types/d3-drag`

# Summary
This package contains type definitions for D3JS d3-drag module ( https://github.com/d3/d3-drag/ ).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/d3-drag

Additional Details
 * Last updated: Wed, 13 Feb 2019 17:05:42 GMT
 * Dependencies: @types/d3-selection
 * Global values: none

# Credits
These definitions were written by Tom Wanzek <https://github.com/tomwanzek>, Alex Ford <https://github.com/gustavderdrache>, Boris Yankov <https://github.com/borisyankov>.
